@@ -1,4 +1,7 @@
 import argparse
+import pandas as pd
+import numpy as np
+
 class addone(object):
 
     number = 0
@@ -7,6 +10,9 @@ class addone(object):
 
     def addtest(self):
         print(self.number + 1)
+        print('Random numpy integer: ' + str(np.random.randint(4)))
+        sample_df = pd.DataFrame(pd.read_csv('addonenishka/sample_data.csv'))
+        print(sample_df.to_markdown())
 
 def main():
     parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
